Test page for 'mark visited'. Make sure the elements are not disturbed when marks are displayed

github
Headers above are testing position: absolute behaviour and overflow handling
This vvv is testing block-like layout handling
Github 1 Github 2 Github 3
hdr Lobsters Recent Comments Search

| Hacker News | new | past | comments | ask | show | jobs | submit

Github
Github
Github
Github
NOTE: this vvvv doesn't work... overflow:auto seems to spoil things :(
whatever SHOULD NOT ADD VISITED MARK HERE!